@@ -10,6 +10,9 @@ try:
 except ImportError:
     from backports import argparse
 
+import pkg_resources  # part of setuptools
+VERSION = pkg_resources.require('ffind')[0].version
+
 # Define colors
 RED_CHARACTER = '\x1b[31m'
 GREEN_CHARACTER = '\x1b[32m'
@@ -39,6 +42,7 @@ VCS_FILES = ('=RELEASE-ID',
              '.cvsignore',
              '.gitignore',)
 
+
 def search(directory, file_pattern, path_match,
            follow_symlinks=True, output=True, colored=True,
            ignore_hidden=True, delete=False, exec_command=False,
@@ -60,12 +64,14 @@ def search(directory, file_pattern, path_match,
 
         # Ignore hidden directories unless explicitly told not to
         if ignore_hidden:
-            sub_folders[:] = [folder for folder in sub_folders if not folder.startswith('.')]
+            sub_folders[:] = [folder for folder in sub_folders
+                              if not folder.startswith('.')]
             files[:] = [file for file in files if not file.startswith('.')]
 
         # Ignore VCS directories
         if ignore_vcs:
-            sub_folders[:] = [folder for folder in sub_folders if folder not in VCS_DIRS]
+            sub_folders[:] = [folder for folder in sub_folders
+                              if folder not in VCS_DIRS]
             files[:] = [file for file in files if file not in VCS_FILES]
 
         # Search in files and subfolders
@@ -178,8 +184,11 @@ def parse_params_and_search():
     parser.add_argument('--ignore-vcs',
                         action='store_true',
                         dest='ignore_vcs',
-                        help='ignore version control system files and directories', 
+                        help='ignore version control system files and '
+                             'directories',
                         default=False)
+    parser.add_argument('--version', action='version',
+                        version='%(prog)s {version}'.format(version=VERSION))
 
     parser.add_argument('dir', nargs='?',
                         help='Directory to search', default='.')
